package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.DeviceManage;
import com.bonus.material.ma.service.IDeviceManageService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 机具设备管理Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "机具设备管理接口")
@RestController
@RequestMapping("/ma_device_manage")
public class DeviceManageController extends BaseController
{
    @Autowired
    private IDeviceManageService deviceManageService;

    /**
     * 查询机具设备管理列表
     */
    @ApiOperation(value = "查询机具设备管理列表")
    @RequiresPermissions("ma:manage:list")
    @GetMapping("/list")
    public TableDataInfo list(DeviceManage deviceManage)
    {
        startPage();
        List<DeviceManage> list = deviceManageService.selectDeviceManageList(deviceManage);
        return getDataTable(list);
    }

    /**
     * 导出机具设备管理列表
     */
    @ApiOperation(value = "导出机具设备管理列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:manage:export")
    @SysLog(title = "机具设备管理", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出机具设备管理")
    @PostMapping("/export")
    public void export(HttpServletResponse response, DeviceManage deviceManage)
    {
        List<DeviceManage> list = deviceManageService.selectDeviceManageList(deviceManage);
        ExcelUtil<DeviceManage> util = new ExcelUtil<DeviceManage>(DeviceManage.class);
        util.exportExcel(response, list, "机具设备管理数据");
    }

    /**
     * 获取机具设备管理详细信息
     */
    @ApiOperation(value = "获取机具设备管理详细信息")
    @RequiresPermissions("ma:manage:query")
    @GetMapping(value = "/{deviceId}")
    public AjaxResult getInfo(@PathVariable("deviceId") Long deviceId)
    {
        return success(deviceManageService.selectDeviceManageByDeviceId(deviceId));
    }

    /**
     * 新增机具设备管理
     */
    @ApiOperation(value = "新增机具设备管理")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:manage:add")
    @SysLog(title = "机具设备管理", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增机具设备管理")
    @PostMapping
    public AjaxResult add(@RequestBody DeviceManage deviceManage)
    {
        return toAjax(deviceManageService.insertDeviceManage(deviceManage));
    }

    /**
     * 修改机具设备管理
     */
    @ApiOperation(value = "修改机具设备管理")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:manage:edit")
    @SysLog(title = "机具设备管理", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改机具设备管理")
    @PutMapping
    public AjaxResult edit(@RequestBody DeviceManage deviceManage)
    {
        return toAjax(deviceManageService.updateDeviceManage(deviceManage));
    }

    /**
     * 删除机具设备管理
     */
    @ApiOperation(value = "删除机具设备管理")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:manage:remove")
    @SysLog(title = "机具设备管理", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除机具设备管理")
	@DeleteMapping("/{deviceIds}")
    public AjaxResult remove(@PathVariable Long[] deviceIds)
    {
        return toAjax(deviceManageService.deleteDeviceManageByDeviceIds(deviceIds));
    }
}
